
| Using the cli is as simple as invoking `generate-python` from a console.

You can run the following to see all the available parameters you can control:

.. code-block:: shell

  generate-python --help

The most common way to generate a new Python Package Project is to run:

.. code-block:: shell

  generate-python

This will prompt you to input some values and create a fresh new Project in the
current directory!

Now, simply `cd` into the generated Project's directory and enjoy some
of the features the generator supplies new projects with!

More on use cases in the next section.
